@@ -4,16 +4,19 @@ import uuid
 
 client = boto3.client("sqs", region_name="us-east-1")
 
-for _ in range(30):
+for _ in range(200):
     client.send_message(
         QueueUrl=(
-            "https://sqs.us-east-1.amazonaws.com/205810638802/integrates_rebase"
+            "https://sqs.us-east-1.amazonaws.com/205810638802/integrates_tasks_dev"
         ),
         MessageBody=json.dumps(
             {
-                "task": "report",
                 "id": uuid.uuid4().hex,
-                "args": ["hello world"],
+                "task": "report",
+                "args": [
+                    uuid.uuid4().hex,
+                    # "ddafdd56-c17f-43c3-9e4c-7e3e074399b9",
+                ],
             }
         ),
     )
