@@ -11,13 +11,14 @@ from asyncio import (
 worker = Worker(
     queues={
         "default": Queue(
-            url="https://sqs.us-east-1.amazonaws.com/205810638802/integrates_rebase"
+            url="https://sqs.us-east-1.amazonaws.com/205810638802/integrates_tasks_dev"
         )
-    }
+    },
+    max_workers=10,
 )
 
 
-@worker.task("report")
+@worker.task("report", queue_name="default")
 async def report(text: str) -> None:
     print(text)
     await sleep(5)
