@@ -2,6 +2,8 @@ from async_sqs_consumer.queue import (
     Queue,
 )
 from async_sqs_consumer.utils import (
+    FailedValidation,
+    TASK_NAME_PREFIX,
     validate_message,
 )
 from async_sqs_consumer.utils.retry import (
@@ -33,17 +35,18 @@ logging.basicConfig(level=logging.INFO)
 LOGGER = logging.getLogger(__name__)
 
 
-class Worker:
+class Worker:  # pylint: disable=too-many-instance-attributes
     def __init__(
-        self,
-        queues: dict[str, Queue],
+        self, queues: dict[str, Queue], max_workers: Optional[int] = None
     ) -> None:
         self.queues = queues
         self.running = False
         self.handlers: dict[str, Callable[..., Any]] = {}
+        self.handlers_by_queue: dict[str, dict[str, Callable[..., Any]]] = {}
         self._events: dict[str, list[Callable[[], None]]] = {}
         self._loop: Optional[asyncio.AbstractEventLoop] = None
         self._tasks: list[asyncio.Task] = []
+        self._max_workers = max_workers or 1024
 
     def _sigint_handler(self, *_args: Any) -> None:
         sys.stdout.write("\b\b\r")
@@ -72,13 +75,15 @@ class Worker:
             _queue_tasks = [
                 task
                 for task in asyncio.all_tasks(self._loop)
-                if task.get_name().startswith("task_queue_")
+                if task.get_name().startswith(TASK_NAME_PREFIX)
             ]
             # TODO: make sure all tasks are finished before finishing the entire process
 
             self._loop.stop()
 
-    def task(self, name: str) -> Callable[[Callable[[], None]], None]:
+    def task(
+        self, name: str, queue_name: Optional[str] = None
+    ) -> Callable[..., None]:
         """A decorator to add a task that could be handled by the worker.
 
         Args:
@@ -89,7 +94,13 @@ class Worker:
         """
 
         def decorator(func: Callable[[], Any]) -> None:
-            self.handlers[name] = func
+            if queue_name:
+                if queue_name not in self.handlers_by_queue:
+                    self.handlers_by_queue[queue_name] = {name: func}
+                else:
+                    self.handlers_by_queue[queue_name][name] = func
+            else:
+                self.handlers[name] = func
 
         return decorator
 
@@ -145,7 +156,11 @@ class Worker:
 
         for queue_name, queue in self.queues.items():
             polling_daemon_task = loop.create_task(
-                queue.start_polling(self._consumer_callback, queue_name)
+                queue.start_polling(
+                    self._consumer_callback,
+                    queue_name,
+                    max_parallel_messages=self._max_workers,
+                )
             )
             self._tasks = [*self._tasks, polling_daemon_task]
 
@@ -155,7 +170,11 @@ class Worker:
         self._loop.run_forever()
 
     def _delete_message(
-        self, _future: asyncio.Future, *, receipt_handle: Any, queue_alias: str
+        self,
+        _future: Optional[asyncio.Future],
+        *,
+        receipt_handle: Any,
+        queue_alias: str,
     ) -> None:
         asyncio.ensure_future(
             self.queues[queue_alias].delete_messages(receipt_handle),
@@ -164,26 +183,28 @@ class Worker:
 
     async def _process_message(
         self, message_content: dict[str, Any], queue_alias: str
-    ) -> None:
+    ) -> bool:
         try:
             body = json.loads(message_content["Body"])
         except json.JSONDecodeError:
-            return
+            return False
 
         if not validate_message(body):
             LOGGER.error("Failed to validate message")
-            return
+            return False
 
-        handler = self.handlers.get(body["task"])
+        handler = self.handlers_by_queue.get(queue_alias, {}).get(body["task"])
+        handler = handler or self.handlers.get(body["task"])
         if not handler:
             LOGGER.warning(
                 "The task %s has not a candidate to be proceeded",
-                body["task_name"],
+                body["task"],
             )
-            return
+            return False
+
         if not self._loop:
             LOGGER.warning("The main event loop is not initialized")
-            return
+            return False
         task = self._loop.create_task(
             retry_call(
                 handler,
@@ -191,7 +212,10 @@ class Worker:
                 fkwargs=body.get("kwargs", {}),
                 tries=body.get("retries", 1),
             ),
-            name=f"task_queue_{queue_alias}_{uuid4().hex[:8]}",
+            name=(
+                f"{TASK_NAME_PREFIX}{queue_alias}"
+                f"_{body['task']}_{uuid4().hex[:8]}"
+            ),
         )
         task.add_done_callback(
             partial(
@@ -200,9 +224,14 @@ class Worker:
                 queue_alias=queue_alias,
             )
         )
+        return True
 
     async def _consumer_callback(
         self, message: dict[str, Any], queue_alias: str
     ) -> None:
         with suppress(asyncio.CancelledError):
-            await self._process_message(message, queue_alias)
+            success = await self._process_message(message, queue_alias)
+            if not success:
+                await self.queues[queue_alias].delete_messages(
+                    message["ReceiptHandle"]
+                )
